@@ -8,10 +8,14 @@ from .core import (
     close,
     execute,
     save,
+    get,
     select,
     select_one,
+    query,
+    query_one,
     do_select,
     do_select_one,
     batch_execute
 )
-from .support import DBError
+from .support import DBError, Dict
+from .engine import Engine, Driver
